@@ -1,13 +1,20 @@
 import etcd3
+from functools import partial
 import json
 import os
 import random
 import time
 
+from shakenfist import baseobject
 from shakenfist.config import config
 from shakenfist.daemons import daemon
 from shakenfist import db
 from shakenfist import logutil
+from shakenfist import net
+from shakenfist.node import (
+    Node, Nodes,
+    active_states_filter as node_active_states_filter,
+    inactive_states_filter as node_inactive_states_filter)
 from shakenfist import util
 from shakenfist import virt
 
@@ -18,7 +25,7 @@ LOG, _ = logutil.setup(__name__)
 class Monitor(daemon.Daemon):
     def _update_power_states(self):
         libvirt = util.get_libvirt()
-        conn = libvirt.open(None)
+        conn = libvirt.open('qemu:///system')
         try:
             seen = []
 
@@ -30,9 +37,9 @@ class Monitor(daemon.Daemon):
                     continue
 
                 instance_uuid = domain.name().split(':')[1]
-                log_ctx = LOG.withInstance(instance_uuid)
+                log_ctx = LOG.with_instance(instance_uuid)
 
-                instance = db.get_instance(instance_uuid)
+                instance = virt.Instance.from_db(instance_uuid)
                 if not instance:
                     # Instance is SF but not in database. Kill to reduce load.
                     log_ctx.warning('Destroying unknown instance')
@@ -40,41 +47,42 @@ class Monitor(daemon.Daemon):
                                  'virsh destroy "sf:%s"' % instance_uuid)
                     continue
 
-                db.place_instance(instance_uuid, config.NODE_NAME)
+                instance.place_instance(config.NODE_NAME)
                 seen.append(domain.name())
 
-                if instance.get('state') == 'deleted':
+                db_state = instance.state
+                if db_state.value == 'deleted':
                     # NOTE(mikal): a delete might be in-flight in the queue.
                     # We only worry about instances which should have gone
                     # away five minutes ago.
-                    if time.time() - instance['state_updated'] < 300:
+                    if time.time() - db_state.update_time < 300:
                         continue
 
-                    db.instance_enforced_deletes_increment(instance_uuid)
-                    attempts = instance.get('enforced_deletes', 0)
+                    instance.enforced_deletes_increment()
+                    attempts = instance._db_get_attribute(
+                        'enforced_deletes')['count']
 
                     if attempts > 5:
-                        # Sometimes we just can't delete the VM. Try the big hammer instead.
-                        log_ctx.warning('Attempting alternate delete method for instance')
+                        # Sometimes we just can't delete the VM. Try the big
+                        # hammer instead.
+                        log_ctx.warning(
+                            'Attempting alternate delete method for instance')
                         util.execute(None,
                                      'virsh destroy "sf:%s"' % instance_uuid)
 
-                        db.add_event('instance', instance_uuid,
-                                     'enforced delete', 'complete', None, None)
+                        instance.add_event('enforced delete', 'complete')
                     else:
-                        i = virt.from_db(instance_uuid)
-                        i.delete()
-                        i.update_instance_state('deleted')
+                        instance.delete()
 
-                    log_ctx.withField('attempt', attempts).warning(
+                    log_ctx.with_field('attempt', attempts).warning(
                         'Deleting stray instance')
 
                     continue
 
                 state = util.extract_power_state(libvirt, domain)
-                db.update_instance_power_state(instance_uuid, state)
+                instance.update_power_state(state)
                 if state == 'crashed':
-                    db.update_instance_state(instance_uuid, 'error')
+                    instance.state = 'error'
 
             # Inactive VMs just have a name, and are powered off
             # in our state system.
@@ -84,46 +92,44 @@ class Monitor(daemon.Daemon):
 
                 if domain_name not in seen:
                     instance_uuid = domain_name.split(':')[1]
-                    log_ctx = LOG.withInstance(instance_uuid)
-                    instance = db.get_instance(instance_uuid)
+                    log_ctx = LOG.with_instance(instance_uuid)
+                    instance = virt.Instance.from_db(instance_uuid)
 
                     if not instance:
-                        # Instance is SF but not in database. Kill because unknown.
+                        # Instance is SF but not in database. Kill because
+                        # unknown.
                         log_ctx.warning('Removing unknown inactive instance')
                         domain = conn.lookupByName(domain_name)
                         domain.undefine()
                         continue
 
-                    if instance.get('state') == 'deleted':
+                    db_state = instance.state
+                    if db_state.value == 'deleted':
                         # NOTE(mikal): a delete might be in-flight in the queue.
                         # We only worry about instances which should have gone
                         # away five minutes ago.
-                        if time.time() - instance['state_updated'] < 300:
+                        if time.time() - db_state.update_time < 300:
                             continue
 
                         domain = conn.lookupByName(domain_name)
                         domain.undefine()
                         log_ctx.info('Detected stray instance')
-                        db.add_event('instance', instance_uuid,
-                                     'deleted stray', 'complete', None, None)
+                        instance.add_event('deleted stray', 'complete')
                         continue
 
-                    db.place_instance(instance_uuid, config.NODE_NAME)
-                    instance_path = os.path.join(
-                        config.get('STORAGE_PATH'), 'instances', instance_uuid)
+                    instance.place_instance(config.NODE_NAME)
 
-                    if not os.path.exists(instance_path):
+                    db_power = instance.power_state
+                    if not os.path.exists(instance.instance_path):
                         # If we're inactive and our files aren't on disk,
                         # we have a problem.
                         log_ctx.info('Detected error state for instance')
-                        db.update_instance_state(instance_uuid, 'error')
+                        instance.state = 'error'
 
-                    elif instance.get('power_state') != 'off':
+                    elif not db_power or db_power['power_state'] != 'off':
                         log_ctx.info('Detected power off for instance')
-                        db.update_instance_power_state(
-                            instance_uuid, 'off')
-                        db.add_event('instance', instance_uuid,
-                                     'detected poweroff', 'complete', None, None)
+                        instance.update_power_state('off')
+                        instance.add_event('detected poweroff', 'complete')
 
         except libvirt.libvirtError as e:
             LOG.error('Failed to lookup all domains: %s' % e)
@@ -152,31 +158,64 @@ class Monitor(daemon.Daemon):
         # Delay first compaction until system startup load has reduced
         last_compaction = time.time() - random.randint(1, 20*60)
 
+        last_loop_run = time.time()
         while True:
             # Update power state of all instances on this hypervisor
             LOG.info('Updating power states')
             self._update_power_states()
 
             # Cleanup soft deleted instances and networks
-            delay = config.get('CLEANER_DELAY')
+            for i in virt.Instances([
+                    virt.inactive_states_filter,
+                    partial(baseobject.state_age_filter, config.get('CLEANER_DELAY'))]):
+                LOG.with_object(i).info('Hard deleting instance')
+                i.hard_delete()
 
-            for i in db.get_stale_instances(delay):
-                LOG.withInstance(i['uuid']).info('Hard deleting instance')
-                db.hard_delete_instance(i['uuid'])
+            for n in net.Networks([
+                    baseobject.inactive_states_filter,
+                    partial(baseobject.state_age_filter, config.get('CLEANER_DELAY'))]):
+                LOG.with_network(n).info('Hard deleting network')
+                n.hard_delete()
 
-            for n in db.get_stale_networks(delay):
-                LOG.withNetwork(n['uuid']).info('Hard deleting network')
-                db.hard_delete_network(n['uuid'])
-
-            for ni in db.get_stale_network_interfaces(delay):
-                LOG.withNetworkInterface(
+            for ni in db.get_stale_network_interfaces(config.get('CLEANER_DELAY')):
+                LOG.with_networkinterface(
                     ni['uuid']).info('Hard deleting network interface')
                 db.hard_delete_network_interface(ni['uuid'])
 
+            for n in Nodes([node_inactive_states_filter]):
+                age = time.time() - n.last_seen
+
+                # Find nodes which have returned from being missing
+                if age < config.NODE_CHECKIN_MAXIMUM:
+                    n.state = Node.STATE_CREATED
+                    LOG.with_object(n).info('Node returned from being missing')
+
+                # Find nodes which have been offline for a long time, unless
+                # this machine has been asleep for a long time (think developer
+                # laptop).
+                if (time.time() - last_loop_run < config.NODE_CHECKIN_MAXIMUM
+                        and age > config.NODE_CHECKIN_MAXIMUM * 10):
+                    n.state = Node.STATE_ERROR
+                    for i in virt.Instances([
+                            virt.healthy_states_filter,
+                            partial(virt.placement_filter, n.uuid)]):
+                        LOG.with_object(i).with_object(n).info(
+                            'Node in error state, erroring instance')
+                        # Note, this queue job is just in case the node comes
+                        # back.
+                        i.enqueue_delete_due_error('Node in error state')
+
+            # Find nodes which haven't checked in recently
+            for n in Nodes([node_active_states_filter]):
+                age = time.time() - n.last_seen
+                if age > config.NODE_CHECKIN_MAXIMUM:
+                    n.state = Node.STATE_MISSING
+
             # Perform etcd maintenance
             if time.time() - last_compaction > 1800:
                 LOG.info('Compacting etcd')
                 self._compact_etcd()
                 last_compaction = time.time()
 
+            last_loop_run = time.time()
             time.sleep(60)
