@@ -3,6 +3,7 @@
 import importlib
 import json
 import multiprocessing
+import os
 from pbr.version import VersionInfo
 import random
 import re
@@ -44,10 +45,10 @@ class RecordedOperation():
             if object_type:
                 db.add_event(object_type, object_uuid,
                              self.operation, 'finish', duration, None)
-                log = LOG.withObj(self.object)
+                log = LOG.with_object(self.object)
             else:
-                log = LOG.withField({'label', self.object})
-        log.withField('duration', duration).info('Finish %s', self.operation)
+                log = LOG.with_field({'label', self.object})
+        log.with_field('duration', duration).info('Finish %s', self.operation)
 
     def unique_label(self):
         if self.object:
@@ -68,9 +69,17 @@ def is_network_node():
     return config.NODE_IP == config.NETWORK_NODE_IP
 
 
-def check_for_interface(name, up=False):
-    stdout, stderr = execute(None,
-                             'ip link show %s' % name, check_exit_code=[0, 1])
+def check_for_interface(name, namespace=None, up=False):
+    in_netns = ''
+    if namespace:
+        if not os.path.exists('/var/run/netns/%s' % namespace):
+            return False
+
+        in_netns = 'ip netns exec %s ' % namespace
+
+    stdout, stderr = execute(
+        None, '%sip link show %s' % (in_netns, name),
+        check_exit_code=[0, 1])
 
     if stderr.rstrip('\n').endswith(' does not exist.'):
         return False
@@ -130,8 +139,8 @@ def get_safe_interface_name(interface):
     if len(interface) > 15:
         orig_interface = interface
         interface = interface[:15]
-        LOG.info('Interface name truncated from %s to %s'
-                 % (orig_interface, interface))
+        LOG.info('Interface name truncated from %s to %s',
+                 orig_interface, interface)
     return interface
 
 
@@ -191,7 +200,7 @@ def get_api_token(base_url, namespace='system'):
     with db.get_lock('namespace', None, namespace,
                      op='Get API token'):
         auth_url = base_url + '/auth'
-        LOG.info('Fetching %s auth token from %s' % (namespace, auth_url))
+        LOG.info('Fetching %s auth token from %s', namespace, auth_url)
         ns = db.get_namespace(namespace)
         if 'service_key' in ns:
             key = ns['service_key']
@@ -257,7 +266,7 @@ def discover_interfaces():
             iface_to_mac[iface_name] = link_ether
 
             if iface_name.startswith('vxlan-'):
-                vxid = int(iface_name.split('-')[1])
+                vxid = int(iface_name.split('-')[1], 16)
                 vxid_to_mac[vxid] = link_ether
 
     return mac_to_iface, iface_to_mac, vxid_to_mac
@@ -279,6 +288,8 @@ def _lock_refresher(locks):
 
 
 def execute(locks, command, check_exit_code=[0], env_variables=None):
+    LOG.info('Executing %s with locks %s', command, locks)
+
     if not locks:
         return processutils.execute(
             command, check_exit_code=check_exit_code,
